@@ -24,7 +24,7 @@ __docformat__ = "restructuredtext en"
 _ = unicode
 
 from yams.buildobjs import (EntityType, RelationDefinition,
-                            String, Float, RichString)
+                            String, Float, RichString, Bytes)
 
 from cubicweb.schema import (RQLVocabularyConstraint, RRQLExpression,
                              ERQLExpression, make_workflowable)
@@ -34,6 +34,9 @@ from cubes.tracker.schema import Project, Ticket, Version, done_in
 from cubes.file.schema import File
 from cubes.card.schema import Card
 
+Project.add_relation(Bytes(description=_("project icon")), name='icon')
+Project.add_relation(String(meta=True, maxsize=50), name='icon_format')
+
 Project.add_relation(String(maxsize=128,
                             description=_('url to project\'s home page. Leave this field '
                                           'empty if the project is fully hosted here.')),
