@@ -3,12 +3,14 @@ from __future__ import with_statement
 
 from datetime import datetime, timedelta
 
+from PIL import Image
+
 from logilab.common.testlib import unittest_main, SkipTest
 
 from cubicweb.devtools import ApptestConfiguration
 from cubicweb.devtools.testlib import AutoPopulateTest
 
-from cubicweb import ValidationError, Unauthorized
+from cubicweb import ValidationError, Unauthorized, Binary
 from cubicweb import NoSelectableObject
 from cubicweb.web.views import actions, workflow, idownloadable
 
@@ -229,14 +231,26 @@ class ProjectTC(TrackerBaseTC):
 
     def test_doap(self):
         self.create_version('0.1.0')
-        self.execute('INSERT MailingList M, EmailAddress E: M name "python-projects", '
-                     'E address "python-projects@logilab.org",  M use_email E, M mailinglist_of P '
+        self.execute('INSERT MailingList M: M name "python-projects", '
+                     'M email_address "python-projects@logilab.org", M mailinglist_of P '
                      'WHERE P is Project')[0]
         self.cubicweb.view('doap')
 
     def test_creator_interested_in(self):
         self.assertEqual(len(self.cubicweb.reverse_interested_in), 1)
 
+    def test_add_icon(self):
+        """ Add an icon to the project, check its new size and format. """
+        # add an icon `tux.png` of size 200 x 232
+        img = Binary.from_file(self.datapath('tux.png'))
+        self.cubicweb.set_attributes(icon=img)
+        self.commit()
+        self.cubicweb.cw_clear_all_caches()
+        # read the icon image, check its size and format
+        icon = Image.open(self.cubicweb.icon)
+        self.assertEqual(50, max(icon.size))
+        self.assertEqual('image/png', self.cubicweb.icon_format)
+
 
 class VersionTC(TrackerBaseTC):
     """Version"""
