@@ -3,7 +3,7 @@ from copy import copy
 from cubicweb.web import stdmsgs, formwidgets, eid_param
 from cubicweb.web.formfields import RelationField
 from cubicweb.web.views.workflow import ChangeStateFormView
-from cubicweb.selectors import is_instance, is_in_state, match_transition
+from cubicweb.predicates import is_instance, is_in_state, match_transition
 
 class NotValidatedChangeView(ChangeStateFormView):
 
@@ -48,12 +48,10 @@ class NotValidatedChangeView(ChangeStateFormView):
                                                        mainform=False)
         followup_form.add_hidden(eid_param('__cloned_eid', followup_tk.eid),
                                  entity.eid)
-        followup_relation_field = RelationField(name='follow_up',
-                                                 label=self._cw._('follow-up ticket'),
-                                                 role='subject',
-                                                 eidparam=True,
-                                                 choices=[(entity.dc_title(), entity.eid)])
-        followup_form.append_field(followup_relation_field)
+        followup_field = RelationField(
+            name='follow_up', role='subject', eidparam=True,
+            choices=[(entity.dc_title(), unicode(entity.eid))])
+        followup_form.append_field(followup_field)
         form.add_subform(followup_form)
         trinfo = self._cw.vreg['etypes'].etype_class('TrInfo')(self._cw)
         trinfo.eid = self._cw.varmaker.next()
