@@ -10,11 +10,12 @@ _ = unicode
 from logilab.common.decorators import monkeypatch
 from logilab.mtconverter import xml_escape
 
-from cubicweb.selectors import one_line_rset, score_entity, is_instance
+from cubicweb.predicates import one_line_rset, score_entity, is_instance
 from cubicweb.view import EntityView
 from cubicweb import tags
 from cubicweb.web import uicfg, action
-from cubicweb.web.views import primary, tabs, baseviews, tableview
+from cubicweb.web.views import (primary, tabs, baseviews, tableview,
+                                idownloadable)
 
 from cubes.testcard import views as testcard
 from cubes.tracker.views import fixed_orderby_rql, project as tracker
@@ -75,6 +76,7 @@ _pvs.tag_subject_of(('*', 'documented_by', '*'), 'hidden')
 _pvdc = uicfg.primaryview_display_ctrl
 for attr in ('homepage', 'downloadurl'):
     _pvdc.tag_attribute(('Project', attr), {'vid': 'urlattr'})
+_pvdc.tag_attribute(('Project', 'icon'), {'showlabel': False})
 
 
 # XXX cleanup or explain View/Tab duality
@@ -105,12 +107,73 @@ class ProjectScreenshotsTab(ProjectScreenshotsView):
     __select__ = tabs.EntityRelationView.__select__ & is_instance('Project')
     title = None # should not appears in possible views
 
+class ProjectListView(baseviews.SameETypeListView):
+    __select__ = (baseviews.SameETypeListView.__select__ &
+                  is_instance("Project"))
+    def call(self, **kwargs):
+        # sort by modification date
+        self.cw_rset = self.cw_rset.sorted_rset(lambda e: e.cw_attr_cache['modification_date'],
+                                                reverse=True)
+        super(ProjectListView, self).call(**kwargs)
+
+class ProjetListItemView(baseviews.SameETypeListItemView):
+    __select__ = (baseviews.SameETypeListItemView.__select__ &
+                  is_instance("Project"))
+
+    def cell_call(self, row, col, **kwargs):
+        self._cw.add_css('cubes.forge.css')
+        entity = self.cw_rset.get_entity(row, col)
+        title = xml_escape(entity.dc_title())
+        updated = entity.cw_attr_cache['modification_date'].strftime('%F, %R')
+        if entity.icon:
+            icon = entity.absolute_url(vid='icon')
+        else:
+            icon = self._cw.data_url('project-icon.png')
+        # project icon
+        self.w(u'<div class="project-item">')
+        self.w(u'<div class="iconwrapper"><img alt="%(title)s" src="%(icon)s"/></div>'
+               % {'title': title, 'icon': xml_escape(icon)})
+        self.w(u'<div class="textwrapper">')
+        # project title, last update date and maybe summary
+        self.w(u'<h3>')
+        self.wview('oneline', entity.as_rset())
+        self.w(u'</h3>')
+        self.w(u'<div class="updated">')
+        self.w(u'<p>')
+        self.w(u'updated on: %s' % updated)
+        self.w(u'</p>')
+        self.w(u'</div>')
+        if entity.summary:
+            self.w(u'<div class="summary">')
+            self.w(u'<p>')
+            self.w(xml_escape(entity.summary))
+            self.w(u'</p>')
+            self.w(u'</div>')
+        self.w(u'</div>')
+        self.w(u'</div>')
+
+class ProjectIconView(idownloadable.DownloadView):
+    __regid__ = 'icon'
+    __select__ = one_line_rset() & is_instance('Project')
+
+    @property
+    def content_type(self):
+        entity = self.cw_rset.complete_entity(self.cw_row or 0, self.cw_col or 0)
+        return entity.icon_format
+
+    def set_request_content_type(self):
+        EntityView.set_request_content_type(self)
+
+    def call(self):
+        entity = self.cw_rset.complete_entity(self.cw_row or 0, self.cw_col or 0)
+        self.w(entity.icon.getvalue())
+
 
 # secondary views ##############################################################
 
 class ExtProjectOutOfContextView(baseviews.OutOfContextView):
-    """project's secondary view display project's url, which is not
-    displayed in the one line / text views
+    """project's out-of-context view display project's url and summary, which
+    are not displayed in the one line / text views
     """
     __select__ = is_instance('ExtProject')
 
@@ -127,7 +190,7 @@ class ProjectTextView(baseviews.TextView):
     __select__ = is_instance('Project')
 
     def cell_call(self, row, col):
-        """ text_view representation of a project """
+        """text representation of a project"""
         entity = self.cw_rset.get_entity(row, col)
         self.w(entity.name)
         state = entity.cw_adapt_to('IWorkflowable').state
@@ -135,6 +198,23 @@ class ProjectTextView(baseviews.TextView):
             self.w(u' [%s]' % self._cw._(state))
 
 
+class ProjectOneLineView(baseviews.OneLineView):
+    __select__ = is_instance('Project')
+
+    def cell_call(self, row, col):
+        """oneline representation of a project, including state information
+        """
+        entity = self.cw_rset.get_entity(row, col)
+        iwf = entity.cw_adapt_to('IWorkflowable')
+        if iwf.state != 'active development':
+            title = 'project %(project)s in state %(state)s' % {
+                'project': entity.name, 'state': iwf.printable_state}
+            self.w(u'<em>%s</em>' % tags.a(entity.name, title=title,
+                                           href=entity.absolute_url()))
+        else:
+            self.w(tags.a(entity.name, href=entity.absolute_url()))
+
+
 class ProjectOutOfContextView(tracker.ProjectOutOfContextView):
     """project's secondary view display project's url, which is not
     displayed in the one line / text views
